from pymammotion.data.model.device_limits import DeviceLimits
from pymammotion.utility.device_type import DeviceType

default_luba_config = {
    "blade_height": {"min": 20, "max": 35},
    "working_speed": {"min": 0.2, "max": 1.2},
    "path_spacing": {"min": 8, "max": 14},
    "work_area_num_max": 60,
    "display_image_type": 0,
}

default_yuka_config = {
    "blade_height": {"min": 0, "max": 0},
    "working_speed": {"min": 0.2, "max": 0.6},
    "path_spacing": {"min": 8, "max": 30},
    "work_area_num_max": 60,
    "display_image_type": 0,
}


class DeviceConfig:
    def __init__(self) -> None:
        # Dictionary to store all device configurations

        # Device mode configurations
        self.default_list = {
            "a1ZU6bdGjaM": {
                "extMod": "LubaAWD1000723",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.4,
                "work_area_num_max": 3,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "a1nf9kRBWoH": {
                "extMod": "LubaAWD3000723",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 6,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "a1ae1QnXZGf": {
                "extMod": "LubaAWD1000743",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 3,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "a1K4Ki2L5rK": {
                "extMod": "LubaAWD5000723",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "a1jOhAYOIG8": {
                "extMod": "LubaAWD5000743LS",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "a1BmXWlsdbA": {
                "extMod": "LubaAWD5000743",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "a1JFpmAV5Ur": {
                "extMod": "Kumar-10",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "a1kweSOPylG": {
                "extMod": "LubaAWD3000723",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 6,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "a1pvCnb3PPu": {
                "extMod": "LubaAWD1000743",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 3,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "a1x0zHD3Xop": {
                "extMod": "LubaAWD5000743LS",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "a1UBFdq6nNz": {
                "extMod": "LubaAWD5000723",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "a1FbaU4Bqk5": {
                "extMod": "LubaAWD5000743",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
        }

        self.inner_list = {
            "HM010060LBAWD10": {
                "extMod": "LubaAWD1000",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 3,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "HM030080LBAWD30": {
                "extMod": "LubaAWD3000",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 6,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "HM050080LBAWD50": {
                "extMod": "LubaAWD5000",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030060LBAWD50OMNI": {
                "extMod": "LubaAWD5000",
                "blade_height_min": 30,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 1,
            },
            "HM060100LBAWD50OMNIH": {
                "extMod": "LubaAWD5000H",
                "blade_height_min": 60,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030070LBVAWD10OMNI": {
                "extMod": "Luba2AWD1000",
                "blade_height_min": 25,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM060100LBVAWD10OMNIH": {
                "extMod": "Luba2AWD1000H",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 10,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030070LBVAWD30OMNI": {
                "extMod": "Luba2AWD3000",
                "blade_height_min": 25,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 20,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM060100LBVAWD30OMNIH": {
                "extMod": "Luba2AWD3000H",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 20,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030070LBVAWD50OMNI": {
                "extMod": "Luba2AWD5000",
                "blade_height_min": 25,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 30,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM060100LBVAWD50OMNIH": {
                "extMod": "Luba2AWD5000H",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 30,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030070LBVAWD100OMNI": {
                "extMod": "Luba2AWD10000",
                "blade_height_min": 25,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM060100LBVAWD100OMNIH": {
                "extMod": "Luba2AWD10000H",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030070LB2PAWD30OMNI": {
                "extMod": "Luba2ProAWD3000",
                "blade_height_min": 25,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 0.8,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM060100LB2PAWD30OMNIH": {
                "extMod": "Luba2ProAWD3000NA",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.8,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030070LB2PAWD50OMNI": {
                "extMod": "Luba2ProAWD5000",
                "blade_height_min": 25,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 1.0,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM060100LB2PAWD50OMNIH": {
                "extMod": "Luba2ProAWD5000NA",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 1.0,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM030070LB2PAWD100OMNI": {
                "extMod": "Luba2ProAWD10000",
                "blade_height_min": 25,
                "blade_height_max": 70,
                "working_speed_min": 0.2,
                "working_speed_max": 1.0,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM060100LB2PAWD100OMNIH": {
                "extMod": "Luba2ProAWD10000NA",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 1.0,
                "work_area_num_max": 60,
                "path_spacing_min": 20,
                "path_spacing_max": 35,
                "display_image_type": 0,
            },
            "HM020065LB2MINIAWD08OMNI": {
                "extMod": "Luba2MiniAWD800",
                "blade_height_min": 20,
                "blade_height_max": 65,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 5,
                "path_spacing_max": 20,
                "display_image_type": 0,
            },
            "HM020065LB2MINIAWD15OMNI": {
                "extMod": "Luba2MiniAWD1500",
                "blade_height_min": 20,
                "blade_height_max": 65,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 5,
                "path_spacing_max": 20,
                "display_image_type": 0,
            },
            "HM020065LB2MINIAWD15OMNILD": {
                "extMod": "Luba2MiniAWD1500Lidar",
                "blade_height_min": 20,
                "blade_height_max": 65,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 5,
                "path_spacing_max": 20,
                "display_image_type": 0,
            },
            "HM055100LB2MINIAWD08OMNIH": {
                "extMod": "Luba2MiniAWD800NA",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 5,
                "path_spacing_max": 20,
                "display_image_type": 0,
            },
            "HM055100LB2MINIAWD15OMNIH": {
                "extMod": "Luba2MiniAWD1500NA",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 5,
                "path_spacing_max": 20,
                "display_image_type": 0,
            },
            "HM055100LB2MINIAWD15OMNIHLD": {
                "extMod": "Luba2MiniAWD1500NALidar",
                "blade_height_min": 55,
                "blade_height_max": 100,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 5,
                "path_spacing_max": 20,
                "display_image_type": 0,
            },
            "HM030070YK06": {
                "extMod": "Yuka600",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030100YK06H": {
                "extMod": "Yuka600NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030070YK10": {
                "extMod": "Yuka1000",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030100YK10H": {
                "extMod": "Yuka1000NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030070YK15": {
                "extMod": "Yuka1500",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030100YK15H": {
                "extMod": "Yuka1500NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM020090YK20": {
                "extMod": "Yuka2000",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030100YK20H": {
                "extMod": "Yuka2000NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM020080YKMINI05": {
                "extMod": "YukaMini500",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM050090YKMINI05H": {
                "extMod": "YukaMini500NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM020080YKMINI08": {
                "extMod": "YukaMini800",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM050090YKMINI08H": {
                "extMod": "YukaMini800NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM020080YKMINI06": {
                "extMod": "YukaMini600",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM020080YKMINI07": {
                "extMod": "YukaMini700",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM050090YKMINI06H": {
                "extMod": "YukaMini600NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM050090YKMINI07H": {
                "extMod": "YukaMini700NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
            "HM020090YKPLUS15": {
                "extMod": "YukaPlus1500",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM020090YKPLUS20": {
                "extMod": "YukaPlus2000",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030100YKPLUS15H": {
                "extMod": "YukaPlus1500NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM030100YKPLUS20H": {
                "extMod": "YukaPlus2000NA",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 15,
                "path_spacing_max": 30,
                "display_image_type": 0,
            },
            "HM020080MN23103": {
                "extMod": "MN231_1",
                "blade_height_min": 0,
                "blade_height_max": 0,
                "working_speed_min": 0.2,
                "working_speed_max": 0.6,
                "work_area_num_max": 60,
                "path_spacing_min": 8,
                "path_spacing_max": 14,
                "display_image_type": 0,
            },
        }

    def get_device_config(self, int_mod_or_key: str) -> dict:
        """Look up device configuration by internal model code

        Args:
            int_mod (str): Internal model code

        Returns:
            dict: Device configuration or None if not found
            :param int_mod_or_key:

        """
        if found := self.inner_list.get(int_mod_or_key):
            return found
        else:
            return self.default_list.get(int_mod_or_key)

    def get_external_model(self, int_mod: str):
        """Get external model name for given internal model code

        Args:
            int_mod (str): Internal model code

        Returns:
            str: External model name or None if not found

        """
        config = self.get_device_config(int_mod)
        return config.get("extMod") if config else None

    def get_working_parameters(self, int_mod_or_key: str) -> DeviceLimits | None:
        """Get working parameters for given internal model code

        Args:
            int_mod (str): Internal model code

        Returns:
            dict: Working parameters or None if not found
            :param int_mod_or_key:

        """
        config = self.get_device_config(int_mod_or_key)
        if not config:
            return None

        return DeviceLimits.from_dict(
            {
                "blade_height": {"min": config["blade_height_min"], "max": config["blade_height_max"]},
                "working_speed": {"min": config["working_speed_min"], "max": config["working_speed_max"]},
                "path_spacing": {"min": config["path_spacing_min"], "max": config["path_spacing_max"]},
                "work_area_num_max": config["work_area_num_max"],
                "display_image_type": config["display_image_type"],
            }
        )

    @staticmethod
    def get_best_default(product_key: str) -> DeviceLimits:
        """Basic fallback if device is offline."""

        if DeviceType.contain_luba_product_key(product_key):
            return DeviceLimits.from_dict(default_luba_config)
        if DeviceType.contain_luba_2_product_key(product_key):
            return DeviceLimits.from_dict(default_luba_config)

        return DeviceLimits.from_dict(default_yuka_config)


# # Usage example:
# def main():
#     device_config = DeviceConfig()
#
#     # Look up a specific device
#     model_code = "HM010060LBAWD10"
#
#     # Get full configuration
#     config = device_config.get_device_config(model_code)
#     print(f"Full configuration for {model_code}:")
#     print(config)
#
#     # Get external model name
#     ext_model = device_config.get_external_model(model_code)
#     print(f"\nExternal model name: {ext_model}")
#
#     # Get working parameters
#     params = device_config.get_working_parameters(model_code)
#     print(f"\nWorking parameters:")
#     print(params)



"""MammotionMQTT."""

import asyncio
import base64
from collections.abc import Awaitable, Callable
import hashlib
import hmac
import json
import logging
from logging import getLogger

import betterproto
from paho.mqtt.client import MQTTMessage

from pymammotion.aliyun.cloud_gateway import CloudIOTGateway
from pymammotion.data.mqtt.event import ThingEventMessage
from pymammotion.data.mqtt.properties import ThingPropertiesMessage
from pymammotion.data.mqtt.status import ThingStatusMessage
from pymammotion.mqtt.linkkit.linkkit import LinkKit
from pymammotion.proto import LubaMsg

logger = getLogger(__name__)


class MammotionMQTT:
    """MQTT client for pymammotion."""

    def __init__(
        self,
        region_id: str,
        product_key: str,
        device_name: str,
        device_secret: str,
        iot_token: str,
        cloud_client: CloudIOTGateway,
        client_id: str | None = None,
    ) -> None:
        """Create instance of MammotionMQTT."""
        super().__init__()
        self._cloud_client = cloud_client
        self.is_connected = False
        self.is_ready = False
        self.on_connected: Callable[[], Awaitable[None]] | None = None
        self.on_ready: Callable[[], Awaitable[None]] | None = None
        self.on_error: Callable[[str], Awaitable[None]] | None = None
        self.on_disconnected: Callable[[], Awaitable[None]] | None = None
        self.on_message: Callable[[str, str, str], Awaitable[None]] | None = None

        self._product_key = product_key
        self._device_name = device_name
        self._device_secret = device_secret
        self._iot_token = iot_token
        self._mqtt_username = f"{device_name}&{product_key}"
        # linkkit provides the correct MQTT service for all of this and uses paho under the hood
        if client_id is None:
            client_id = f"python-{device_name}"
        self._mqtt_client_id = f"{client_id}|securemode=2,signmethod=hmacsha1|"
        sign_content = f"clientId{client_id}deviceName{device_name}productKey{product_key}"
        self._mqtt_password = hmac.new(
            device_secret.encode("utf-8"), sign_content.encode("utf-8"), hashlib.sha1
        ).hexdigest()

        self._client_id = client_id
        self.loop = asyncio.get_running_loop()

        self._linkkit_client = LinkKit(
            region_id,
            product_key,
            device_name,
            device_secret,
            auth_type="",
            client_id=client_id,
            password=self._mqtt_password,
            username=self._mqtt_username,
        )

        self._linkkit_client.enable_logger(level=logging.ERROR)
        self._linkkit_client.on_connect = self._thing_on_connect
        self._linkkit_client.on_disconnect = self._on_disconnect
        self._linkkit_client.on_thing_enable = self._thing_on_thing_enable
        self._linkkit_client.on_topic_message = self._thing_on_topic_message
        self._mqtt_host = f"{self._product_key}.iot-as-mqtt.{region_id}.aliyuncs.com"

    def connect_async(self) -> None:
        """Connect async to MQTT Server."""
        logger.info("Connecting...")
        if self._linkkit_client.check_state() is LinkKit.LinkKitState.INITIALIZED:
            self._linkkit_client.thing_setup()
        self._linkkit_client.connect_async()

    def disconnect(self) -> None:
        """Disconnect from MQTT Server."""
        logger.info("Disconnecting...")

        self._linkkit_client.disconnect()

    def _thing_on_thing_enable(self, user_data) -> None:
        """Is called when Thing is enabled."""
        logger.debug("on_thing_enable")
        self.is_connected = True
        # logger.debug('subscribe_topic, topic:%s' % echo_topic)
        # self._linkkit_client.subscribe_topic(echo_topic, 0)
        self._linkkit_client.subscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/account/bind_reply"
        )
        self._linkkit_client.subscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/event/property/post_reply"
        )
        self._linkkit_client.subscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/wifi/status/notify"
        )
        self._linkkit_client.subscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/wifi/connect/event/notify"
        )
        self._linkkit_client.subscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/_thing/event/notify"
        )
        self._linkkit_client.subscribe_topic(f"/sys/{self._product_key}/{self._device_name}/app/down/thing/events")
        self._linkkit_client.subscribe_topic(f"/sys/{self._product_key}/{self._device_name}/app/down/thing/status")
        self._linkkit_client.subscribe_topic(f"/sys/{self._product_key}/{self._device_name}/app/down/thing/properties")
        self._linkkit_client.subscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/model/down_raw"
        )

        self._linkkit_client.publish_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/up/account/bind",
            json.dumps(
                {
                    "id": "msgid1",
                    "version": "1.0",
                    "request": {"clientId": self._mqtt_username},
                    "params": {"iotToken": self._iot_token},
                }
            ),
        )

        if self.on_ready:
            self.is_ready = True
            future = asyncio.run_coroutine_threadsafe(self.on_ready(), self.loop)
            asyncio.wrap_future(future, loop=self.loop)
        # self._linkkit_client.query_ota_firmware()
        # command = MammotionCommand(device_name="Luba")
        # self._cloud_client.send_cloud_command(command.get_report_cfg())

    def unsubscribe(self) -> None:
        self._linkkit_client.unsubscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/account/bind_reply"
        )
        self._linkkit_client.unsubscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/event/property/post_reply"
        )
        self._linkkit_client.unsubscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/wifi/status/notify"
        )
        self._linkkit_client.unsubscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/wifi/connect/event/notify"
        )
        self._linkkit_client.unsubscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/_thing/event/notify"
        )
        self._linkkit_client.unsubscribe_topic(f"/sys/{self._product_key}/{self._device_name}/app/down/thing/events")
        self._linkkit_client.unsubscribe_topic(f"/sys/{self._product_key}/{self._device_name}/app/down/thing/status")
        self._linkkit_client.unsubscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/properties"
        )
        self._linkkit_client.unsubscribe_topic(
            f"/sys/{self._product_key}/{self._device_name}/app/down/thing/model/down_raw"
        )

    def _thing_on_topic_message(self, topic, payload, qos, user_data) -> None:
        """Is called when thing topic comes in."""
        logger.debug(
            "on_topic_message, receive message, topic:%s, payload:%s, qos:%d",
            topic,
            payload,
            qos,
        )
        payload = json.loads(payload)
        iot_id = payload.get("params", {}).get("iotId", "")
        if iot_id != "" and self.on_message:
            future = asyncio.run_coroutine_threadsafe(self.on_message(topic, payload, iot_id), self.loop)
            asyncio.wrap_future(future, loop=self.loop)

    def _thing_on_connect(self, session_flag, rc, user_data) -> None:
        """Is called on thing connect."""
        self.is_connected = True
        if self.on_connected is not None:
            future = asyncio.run_coroutine_threadsafe(self.on_connected(), self.loop)
            asyncio.wrap_future(future, loop=self.loop)

        logger.debug("on_connect, session_flag:%d, rc:%d", session_flag, rc)

        # self._linkkit_client.subscribe_topic(f"/sys/{self._product_key}/{self._device_name}/#")

    def _on_disconnect(self, _client, _userdata) -> None:
        """Is called on disconnect."""
        if self._linkkit_client.check_state() is LinkKit.LinkKitState.DISCONNECTED:
            logger.info("Disconnected")
            self.is_connected = False
            self.is_ready = False
            if self.on_disconnected:
                future = asyncio.run_coroutine_threadsafe(self.on_disconnected(), self.loop)
                asyncio.wrap_future(future, loop=self.loop)

    def _on_message(self, _client, _userdata, message: MQTTMessage) -> None:
        """Is called when message is received."""
        logger.info("Message on topic %s", message.topic)

        payload = json.loads(message.payload)
        if message.topic.endswith("/app/down/thing/events"):
            event = ThingEventMessage(**payload)
            params = event.params
            if params.identifier == "device_protobuf_msg_event":
                content = LubaMsg().parse(base64.b64decode(params.value.content))

                logger.info("Unhandled protobuf event: %s", betterproto.which_one_of(content, "LubaSubMsg"))
            elif params.identifier == "device_warning_event":
                logger.debug("identifier event: %s", params.identifier)
            else:
                logger.info("Unhandled event: %s", params.identifier)
        elif message.topic.endswith("/app/down/thing/status"):
            # the tell if a device has come back online
            # lastStatus
            # 1 online?
            # 3 offline?
            status = ThingStatusMessage(**payload)
            logger.debug(status.params.status.value)
        elif message.topic.endswith("/app/down/thing/properties"):
            properties = ThingPropertiesMessage(**payload)
            logger.debug("properties: %s", properties)
        else:
            logger.debug("Unhandled topic: %s", message.topic)
            logger.debug(payload)

    def get_cloud_client(self) -> CloudIOTGateway:
        """Return internal cloud client."""
        return self._cloud_client



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pymammotion/proto/mctrl_nav.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pymammotion.proto import common_pb2 as pymammotion_dot_proto_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!pymammotion/proto/mctrl_nav.proto\x1a\x1epymammotion/proto/common.proto\"\'\n\x0bNavLatLonUp\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lon\x18\x02 \x01(\x01\"!\n\x0eNavBorderState\x12\x0f\n\x07\x62\x64state\x18\x01 \x01(\x05\"\xc9\x01\n\x08NavPosUp\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\x0e\n\x06toward\x18\x04 \x01(\x05\x12\r\n\x05stars\x18\x05 \x01(\x05\x12\x0b\n\x03\x61ge\x18\x06 \x01(\x02\x12\x11\n\tlatStddev\x18\x07 \x01(\x02\x12\x11\n\tlonStddev\x18\x08 \x01(\x02\x12\x11\n\tl2dfStars\x18\t \x01(\x05\x12\x0f\n\x07posType\x18\n \x01(\x05\x12\x0f\n\x07\x63HashId\x18\x0b \x01(\x03\x12\x10\n\x08posLevel\x18\x0c \x01(\x05\":\n\x13NavBorderDataGetAck\x12\r\n\x05jobId\x18\x01 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x02 \x01(\x05\"Z\n\x15NavObstiBorderDataGet\x12\x15\n\robstacleIndex\x18\x01 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x02 \x01(\x05\x12\x14\n\x0cobstaclesLen\x18\x03 \x01(\x05\"G\n\x18NavObstiBorderDataGetAck\x12\x15\n\robstacleIndex\x18\x01 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x02 \x01(\x05\"d\n\x0eNavCHlLineData\x12\x12\n\nstartJobRI\x18\x01 \x01(\x05\x12\x10\n\x08\x65ndJobRI\x18\x02 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannelLineLen\x18\x04 \x01(\x05\"O\n\x11NavCHlLineDataAck\x12\x12\n\nstartJobRI\x18\x01 \x01(\x05\x12\x10\n\x08\x65ndJobRI\x18\x02 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x03 \x01(\x05\"\x7f\n\x0bNavTaskInfo\x12\x0c\n\x04\x61rea\x18\x01 \x01(\x05\x12\x0c\n\x04time\x18\x02 \x01(\x05\x12\x10\n\x08\x61llFrame\x18\x03 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x04 \x01(\x05\x12\x0f\n\x07pathlen\x18\x05 \x01(\x05\x12\x1b\n\x02\x64\x63\x18\x06 \x03(\x0b\x32\x0f.CommDataCouple\"J\n\x10NavBorderDataGet\x12\r\n\x05jobId\x18\x01 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x02 \x01(\x05\x12\x11\n\tborderLen\x18\x03 \x01(\x05\"\x91\x01\n\x0cNavOptLineUp\x12\x12\n\nstartJobRI\x18\x01 \x01(\x05\x12\x10\n\x08\x65ndJobRI\x18\x02 \x01(\x05\x12\x10\n\x08\x61llFrame\x18\x03 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x04 \x01(\x05\x12\x16\n\x0e\x63hannelDataLen\x18\x05 \x01(\x05\x12\x1b\n\x02\x64\x63\x18\x06 \x03(\x0b\x32\x0f.CommDataCouple\"~\n\x11NavOptiBorderInfo\x12\r\n\x05jobId\x18\x01 \x01(\x05\x12\x10\n\x08\x61llFrame\x18\x02 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x03 \x01(\x05\x12\x15\n\rborderDataLen\x18\x04 \x01(\x05\x12\x1b\n\x02\x64\x63\x18\x05 \x03(\x0b\x32\x0f.CommDataCouple\"\x81\x01\n\rNavOptObsInfo\x12\x12\n\nobstacleId\x18\x01 \x01(\x05\x12\x10\n\x08\x61llFrame\x18\x02 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x03 \x01(\x05\x12\x17\n\x0fobstacleDataLen\x18\x04 \x01(\x05\x12\x1b\n\x02\x64\x63\x18\x05 \x03(\x0b\x32\x0f.CommDataCouple\"\xb4\x01\n\x0bNavStartJob\x12\r\n\x05jobId\x18\x01 \x01(\x03\x12\x0e\n\x06jobVer\x18\x02 \x01(\x05\x12\x0f\n\x07jobMode\x18\x03 \x01(\x05\x12\x13\n\x0brainTactics\x18\x04 \x01(\x05\x12\x13\n\x0bknifeHeight\x18\x05 \x01(\x05\x12\r\n\x05speed\x18\x06 \x01(\x02\x12\x14\n\x0c\x63hannelWidth\x18\x07 \x01(\x05\x12\x11\n\tUltraWave\x18\x08 \x01(\x05\x12\x13\n\x0b\x63hannelMode\x18\t \x01(\x05\"\'\n\x0fNavTaskProgress\x12\x14\n\x0ctaskProgress\x18\x01 \x01(\x05\"\x1e\n\x0bNavResFrame\x12\x0f\n\x07\x66rameid\x18\x01 \x01(\x05\"|\n\x0eNavGetHashList\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06subCmd\x18\x02 \x01(\x05\x12\x12\n\ntotalFrame\x18\x03 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x04 \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\x05 \x01(\x06\x12\x10\n\x08reserved\x18\x06 \x01(\t\"\xb4\x01\n\x11NavGetHashListAck\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06subCmd\x18\x02 \x01(\x05\x12\x12\n\ntotalFrame\x18\x03 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x04 \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\x05 \x01(\x06\x12\x0f\n\x07hashLen\x18\x06 \x01(\x05\x12\x10\n\x08reserved\x18\x07 \x01(\t\x12\x0e\n\x06result\x18\x08 \x01(\x05\x12\x12\n\ndataCouple\x18\r \x03(\x03\"\xd6\x01\n\x0eNavGetCommData\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06subCmd\x18\x02 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0c\n\x04hash\x18\x05 \x01(\x03\x12\x15\n\rpaternalHashA\x18\x06 \x01(\x03\x12\x15\n\rpaternalHashB\x18\x07 \x01(\x03\x12\x12\n\ntotalFrame\x18\x08 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\t \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\n \x01(\x06\x12\x10\n\x08reserved\x18\x0b \x01(\t\"\x1a\n\tAreaLabel\x12\r\n\x05label\x18\x01 \x01(\t\"\xbe\x02\n\x11NavGetCommDataAck\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06subCmd\x18\x02 \x01(\x05\x12\x0e\n\x06result\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\x05\x12\x0c\n\x04type\x18\x05 \x01(\x05\x12\x0c\n\x04Hash\x18\x06 \x01(\x06\x12\x15\n\rpaternalHashA\x18\x07 \x01(\x06\x12\x15\n\rpaternalHashB\x18\x08 \x01(\x06\x12\x12\n\ntotalFrame\x18\t \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\n \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\x0b \x01(\x06\x12\x0f\n\x07\x64\x61taLen\x18\x0c \x01(\x05\x12#\n\ndataCouple\x18\r \x03(\x0b\x32\x0f.CommDataCouple\x12\x10\n\x08reserved\x18\x0e \x01(\t\x12\x1d\n\tareaLabel\x18\x0f \x01(\x0b\x32\n.AreaLabel\"\xde\x02\n\x0fNavReqCoverPath\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\r\n\x05jobId\x18\x02 \x01(\x06\x12\x0e\n\x06jobVer\x18\x03 \x01(\x05\x12\x0f\n\x07jobMode\x18\x04 \x01(\x05\x12\x0e\n\x06subCmd\x18\x05 \x01(\x05\x12\x10\n\x08\x65\x64geMode\x18\x06 \x01(\x05\x12\x13\n\x0bknifeHeight\x18\x07 \x01(\x05\x12\x14\n\x0c\x63hannelWidth\x18\x08 \x01(\x05\x12\x11\n\tUltraWave\x18\t \x01(\x05\x12\x13\n\x0b\x63hannelMode\x18\n \x01(\x05\x12\x0e\n\x06toward\x18\x0b \x01(\x05\x12\r\n\x05speed\x18\x0c \x01(\x02\x12\x11\n\tzoneHashs\x18\r \x03(\x06\x12\x10\n\x08pathHash\x18\x0e \x01(\x06\x12\x10\n\x08reserved\x18\x0f \x01(\t\x12\x0e\n\x06result\x18\x10 \x01(\x05\x12\x13\n\x0btoward_mode\x18\x11 \x01(\x05\x12\x1d\n\x15toward_included_angle\x18\x12 \x01(\x05\"\xa7\x03\n\x15NavUploadZigZagResult\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\r\n\x05jobId\x18\x02 \x01(\x06\x12\x0e\n\x06jobVer\x18\x03 \x01(\x05\x12\x0e\n\x06result\x18\x04 \x01(\x05\x12\x0c\n\x04\x61rea\x18\x05 \x01(\x05\x12\x0c\n\x04time\x18\x06 \x01(\x05\x12\x14\n\x0ctotalZoneNum\x18\x07 \x01(\x05\x12\x1a\n\x12\x63urrentZonePathNum\x18\x08 \x01(\x05\x12\x19\n\x11\x63urrentZonePathId\x18\t \x01(\x05\x12\x13\n\x0b\x63urrentZone\x18\n \x01(\x05\x12\x13\n\x0b\x63urrentHash\x18\x0b \x01(\x06\x12\x12\n\ntotalFrame\x18\x0c \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\r \x01(\x05\x12\x13\n\x0b\x63hannelMode\x18\x0e \x01(\x05\x12\x15\n\rchannelModeId\x18\x0f \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\x10 \x01(\x06\x12\x0f\n\x07\x64\x61taLen\x18\x11 \x01(\x05\x12\x10\n\x08reserved\x18\x12 \x01(\t\x12#\n\ndataCouple\x18\x13 \x03(\x0b\x32\x0f.CommDataCouple\x12\x0e\n\x06subCmd\x18\x14 \x01(\x05\"\xb0\x01\n\x18NavUploadZigZagResultAck\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x13\n\x0b\x63urrentZone\x18\x02 \x01(\x05\x12\x13\n\x0b\x63urrentHash\x18\x03 \x01(\x06\x12\x12\n\ntotalFrame\x18\x04 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x05 \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\x06 \x01(\x06\x12\x10\n\x08reserved\x18\x07 \x01(\t\x12\x0e\n\x06subCmd\x18\x08 \x01(\x05\"M\n\x0bNavTaskCtrl\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\x12\x0e\n\x06result\x18\x03 \x01(\x05\x12\x10\n\x08reserved\x18\x04 \x01(\t\"o\n\x0bNavTaskIdRw\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06subCmd\x18\x02 \x01(\x05\x12\x10\n\x08taskName\x18\x03 \x01(\t\x12\x0e\n\x06taskId\x18\x04 \x01(\t\x12\x0e\n\x06result\x18\x05 \x01(\x05\x12\x10\n\x08reserved\x18\x06 \x01(\t\"J\n\x12NavSysHashOverview\x12\x1a\n\x12\x63ommonhashOverview\x18\x01 \x01(\x06\x12\x18\n\x10pathHashOverview\x18\x02 \x01(\x06\"i\n\x11NavTaskBreakPoint\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\x0e\n\x06toward\x18\x03 \x01(\x05\x12\x0c\n\x04\x66lag\x18\x04 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\x05\x12\x10\n\x08zoneHash\x18\x06 \x01(\x06\"\xc2\x05\n\rNavPlanJobSet\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06subCmd\x18\x02 \x01(\x05\x12\x0c\n\x04\x61rea\x18\x03 \x01(\x05\x12\x10\n\x08workTime\x18\x04 \x01(\x05\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0e\n\x06userId\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65viceId\x18\x08 \x01(\t\x12\x0e\n\x06planId\x18\t \x01(\t\x12\x0e\n\x06taskId\x18\n \x01(\t\x12\r\n\x05jobId\x18\x0b \x01(\t\x12\x11\n\tstartTime\x18\x0c \x01(\t\x12\x0f\n\x07\x65ndTime\x18\r \x01(\t\x12\x0c\n\x04week\x18\x0e \x01(\x05\x12\x13\n\x0bknifeHeight\x18\x0f \x01(\x05\x12\r\n\x05model\x18\x10 \x01(\x05\x12\x10\n\x08\x65\x64geMode\x18\x11 \x01(\x05\x12\x14\n\x0crequiredTime\x18\x12 \x01(\x05\x12\x12\n\nrouteAngle\x18\x13 \x01(\x05\x12\x12\n\nrouteModel\x18\x14 \x01(\x05\x12\x14\n\x0crouteSpacing\x18\x15 \x01(\x05\x12\x19\n\x11ultrasonicBarrier\x18\x16 \x01(\x05\x12\x14\n\x0ctotalPlanNum\x18\x17 \x01(\x05\x12\x11\n\tPlanIndex\x18\x18 \x01(\x05\x12\x0e\n\x06result\x18\x19 \x01(\x05\x12\r\n\x05speed\x18\x1a \x01(\x02\x12\x10\n\x08taskName\x18\x1b \x01(\t\x12\x0f\n\x07jobName\x18\x1c \x01(\t\x12\x11\n\tzoneHashs\x18\x1d \x03(\x06\x12\x10\n\x08reserved\x18\x1e \x01(\t\x12\x11\n\tstartDate\x18\x1f \x01(\t\x12\x0f\n\x07\x65ndDate\x18  \x01(\t\x12\x13\n\x0btriggerType\x18! \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\" \x01(\x05\x12\r\n\x05weeks\x18# \x03(\x07\x12\x18\n\x10remained_seconds\x18$ \x01(\x03\x12\x12\n\ntowardMode\x18% \x01(\x05\x12\x1b\n\x13towardIncludedAngle\x18& \x01(\x05\"\x86\x01\n\x10NavUnableTimeSet\x12\x0e\n\x06subCmd\x18\x01 \x01(\x05\x12\x10\n\x08\x64\x65viceId\x18\x02 \x01(\t\x12\x17\n\x0funableStartTime\x18\x03 \x01(\t\x12\x15\n\runableEndTime\x18\x04 \x01(\t\x12\x0e\n\x06result\x18\x05 \x01(\x05\x12\x10\n\x08reserved\x18\x06 \x01(\t\"6\n\x0e\x63hargePileType\x12\x0e\n\x06toward\x18\x01 \x01(\x05\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\"J\n\x11SimulationCmdData\x12\x0e\n\x06subCmd\x18\x01 \x01(\x05\x12\x10\n\x08param_id\x18\x02 \x01(\x05\x12\x13\n\x0bparam_value\x18\x03 \x03(\x05\"%\n\x13WorkReportUpdateCmd\x12\x0e\n\x06subCmd\x18\x01 \x01(\x05\"<\n\x13WorkReportUpdateAck\x12\x13\n\x0bupdate_flag\x18\x01 \x01(\x08\x12\x10\n\x08info_num\x18\x02 \x01(\x05\"7\n\x11WorkReportCmdData\x12\x0e\n\x06subCmd\x18\x01 \x01(\x05\x12\x12\n\ngetInfoNum\x18\x02 \x01(\x05\"\x8e\x02\n\x11WorkReportInfoAck\x12\x16\n\x0einterrupt_flag\x18\x01 \x01(\x08\x12\x17\n\x0fstart_work_time\x18\x02 \x01(\x03\x12\x15\n\rend_work_time\x18\x03 \x01(\x03\x12\x16\n\x0ework_time_used\x18\x04 \x01(\x05\x12\x11\n\twork_ares\x18\x05 \x01(\x01\x12\x15\n\rwork_progress\x18\x06 \x01(\x05\x12\x17\n\x0fheight_of_knife\x18\x07 \x01(\x05\x12\x11\n\twork_type\x18\x08 \x01(\x05\x12\x13\n\x0bwork_result\x18\t \x01(\x05\x12\x15\n\rtotal_ack_num\x18\n \x01(\x05\x12\x17\n\x0f\x63urrent_ack_num\x18\x0b \x01(\x05\"\xb2\x01\n\x19\x61pp_request_cover_paths_t\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06subCmd\x18\x02 \x01(\x05\x12\x12\n\ntotalFrame\x18\x03 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x04 \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\x05 \x01(\x06\x12\x16\n\x0etransaction_id\x18\x06 \x01(\x03\x12\x10\n\x08reserved\x18\x07 \x03(\x03\x12\x11\n\thash_list\x18\x08 \x03(\x06\"\x99\x01\n\x13\x63over_path_packet_t\x12\x11\n\tpath_hash\x18\x01 \x01(\x06\x12\x11\n\tpath_type\x18\x02 \x01(\x05\x12\x12\n\npath_total\x18\x03 \x01(\x05\x12\x10\n\x08path_cur\x18\x04 \x01(\x05\x12\x11\n\tzone_hash\x18\x05 \x01(\x06\x12#\n\ndataCouple\x18\x06 \x03(\x0b\x32\x0f.CommDataCouple\"\xb2\x02\n\x13\x63over_path_upload_t\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0e\n\x06result\x18\x02 \x01(\x05\x12\x0e\n\x06subCmd\x18\x03 \x01(\x05\x12\x0c\n\x04\x61rea\x18\x04 \x01(\x05\x12\x0c\n\x04time\x18\x05 \x01(\x05\x12\x12\n\ntotalFrame\x18\x06 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x07 \x01(\x05\x12\x16\n\x0etotal_path_num\x18\x08 \x01(\x05\x12\x16\n\x0evaild_path_num\x18\t \x01(\x05\x12\x10\n\x08\x64\x61taHash\x18\n \x01(\x06\x12\x16\n\x0etransaction_id\x18\x0b \x01(\x03\x12\x10\n\x08reserved\x18\x0c \x03(\x03\x12\x0f\n\x07\x64\x61taLen\x18\r \x01(\x05\x12*\n\x0cpath_packets\x18\x0e \x03(\x0b\x32\x14.cover_path_packet_t\"M\n\x14zone_start_precent_t\x12\x10\n\x08\x64\x61taHash\x18\x01 \x01(\x06\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\r\n\x05index\x18\x04 \x01(\x05\",\n\x0fvision_ctrl_msg\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0b\n\x03\x63md\x18\x02 \x01(\x05\"<\n\x11nav_sys_param_msg\x12\n\n\x02rw\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\x05\"Q\n\x15nav_plan_task_execute\x12\x0e\n\x06subCmd\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06result\x18\x04 \x01(\x05\"y\n\tcostmap_t\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x10\n\x08\x63\x65nter_x\x18\x03 \x01(\x02\x12\x10\n\x08\x63\x65nter_y\x18\x04 \x01(\x02\x12\x0b\n\x03yaw\x18\x05 \x01(\x02\x12\x0b\n\x03res\x18\x06 \x01(\x02\x12\x0f\n\x07\x63ostmap\x18\x07 \x03(\x05\"/\n\x13plan_task_name_id_t\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"<\n\x15nav_get_all_plan_task\x12#\n\x05tasks\x18\x01 \x03(\x0b\x32\x14.plan_task_name_id_t\"c\n\x0eNavTaskCtrlAck\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\x12\x0e\n\x06result\x18\x03 \x01(\x05\x12\x11\n\tnav_state\x18\x04 \x01(\x05\x12\x10\n\x08reserved\x18\x05 \x01(\t\"Z\n\rNavMapNameMsg\x12\n\n\x02rw\x18\x01 \x01(\x05\x12\x0c\n\x04hash\x18\x02 \x01(\x06\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06result\x18\x04 \x01(\x05\x12\x11\n\tdevice_id\x18\x05 \x01(\t\"\x94\x02\n\rsvg_message_t\x12\x0e\n\x06x_move\x18\x01 \x01(\x01\x12\x0e\n\x06y_move\x18\x02 \x01(\x01\x12\r\n\x05scale\x18\x03 \x01(\x01\x12\x0e\n\x06rotate\x18\x04 \x01(\x01\x12\x14\n\x0c\x62\x61se_width_m\x18\x05 \x01(\x01\x12\x16\n\x0e\x62\x61se_width_pix\x18\x07 \x01(\x05\x12\x15\n\rbase_height_m\x18\x06 \x01(\x01\x12\x17\n\x0f\x62\x61se_height_pix\x18\x08 \x01(\x05\x12\x12\n\ndata_count\x18\x0c \x01(\x05\x12\x10\n\x08hide_svg\x18\r \x01(\x08\x12\x12\n\nname_count\x18\x0b \x01(\x05\x12\x15\n\rsvg_file_name\x18\t \x01(\t\x12\x15\n\rsvg_file_data\x18\n \x01(\t\"\xca\x01\n\x0eSvgMessageAckT\x12\x0c\n\x04pver\x18\x01 \x01(\x05\x12\x0f\n\x07sub_cmd\x18\x02 \x01(\x05\x12\x13\n\x0btotal_frame\x18\x03 \x01(\x05\x12\x15\n\rcurrent_frame\x18\x04 \x01(\x05\x12\x11\n\tdata_hash\x18\x05 \x01(\x06\x12\x17\n\x0fpaternal_hash_a\x18\x06 \x01(\x06\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\x0e\n\x06result\x18\x08 \x01(\x05\x12#\n\x0bsvg_message\x18\t \x01(\x0b\x32\x0e.svg_message_t\"*\n\x0c\x41reaHashName\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x01 \x01(\x06\"L\n\x15\x41ppGetAllAreaHashName\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12 \n\thashnames\x18\x02 \x03(\x0b\x32\r.AreaHashName\"\xe3\x14\n\x07MctlNav\x12$\n\x0ctoapp_lat_up\x18\x01 \x01(\x0b\x32\x0c.NavLatLonUpH\x00\x12!\n\x0ctoapp_pos_up\x18\x02 \x01(\x0b\x32\t.NavPosUpH\x00\x12.\n\x13todev_chl_line_data\x18\x03 \x01(\x0b\x32\x0f.NavCHlLineDataH\x00\x12\'\n\x0ftoapp_task_info\x18\x04 \x01(\x0b\x32\x0c.NavTaskInfoH\x00\x12*\n\x11toapp_opt_line_up\x18\x05 \x01(\x0b\x32\r.NavOptLineUpH\x00\x12\x33\n\x15toapp_opt_border_info\x18\x06 \x01(\x0b\x32\x12.NavOptiBorderInfoH\x00\x12,\n\x12toapp_opt_obs_info\x18\x07 \x01(\x0b\x32\x0e.NavOptObsInfoH\x00\x12+\n\x13todev_task_info_ack\x18\x08 \x01(\x0b\x32\x0c.NavResFrameH\x00\x12\x31\n\x19todev_opt_border_info_ack\x18\t \x01(\x0b\x32\x0c.NavResFrameH\x00\x12.\n\x16todev_opt_obs_info_ack\x18\n \x01(\x0b\x32\x0c.NavResFrameH\x00\x12-\n\x15todev_opt_line_up_ack\x18\x0b \x01(\x0b\x32\x0c.NavResFrameH\x00\x12*\n\x0ftoapp_chgpileto\x18\x0c \x01(\x0b\x32\x0f.chargePileTypeH\x00\x12\x17\n\rtodev_sustask\x18\r \x01(\x05H\x00\x12\x18\n\x0etodev_rechgcmd\x18\x0e \x01(\x05H\x00\x12\x17\n\rtodev_edgecmd\x18\x0f \x01(\x05H\x00\x12\x1b\n\x11todev_draw_border\x18\x10 \x01(\x05H\x00\x12\x1f\n\x15todev_draw_border_end\x18\x11 \x01(\x05H\x00\x12\x18\n\x0etodev_draw_obs\x18\x12 \x01(\x05H\x00\x12\x1c\n\x12todev_draw_obs_end\x18\x13 \x01(\x05H\x00\x12\x18\n\x0etodev_chl_line\x18\x14 \x01(\x05H\x00\x12\x1c\n\x12todev_chl_line_end\x18\x15 \x01(\x05H\x00\x12\x19\n\x0ftodev_save_task\x18\x16 \x01(\x05H\x00\x12\x1d\n\x13todev_cancel_suscmd\x18\x17 \x01(\x05H\x00\x12\x1e\n\x14todev_reset_chg_pile\x18\x18 \x01(\x05H\x00\x12\x1f\n\x15todev_cancel_draw_cmd\x18\x19 \x01(\x05H\x00\x12$\n\x1atodev_one_touch_leave_pile\x18\x1a \x01(\x05H\x00\x12&\n\x0etodev_mow_task\x18\x1b \x01(\x0b\x32\x0c.NavStartJobH\x00\x12\'\n\x0ctoapp_bstate\x18\x1c \x01(\x0b\x32\x0f.NavBorderStateH\x00\x12\x1a\n\x10todev_lat_up_ack\x18\x1d \x01(\x05H\x00\x12(\n\rtodev_gethash\x18\x1e \x01(\x0b\x32\x0f.NavGetHashListH\x00\x12/\n\x11toapp_gethash_ack\x18\x1f \x01(\x0b\x32\x12.NavGetHashListAckH\x00\x12/\n\x14todev_get_commondata\x18  \x01(\x0b\x32\x0f.NavGetCommDataH\x00\x12\x36\n\x18toapp_get_commondata_ack\x18! \x01(\x0b\x32\x12.NavGetCommDataAckH\x00\x12\x31\n\x15\x62idire_reqconver_path\x18\" \x01(\x0b\x32\x10.NavReqCoverPathH\x00\x12.\n\x0ctoapp_zigzag\x18# \x01(\x0b\x32\x16.NavUploadZigZagResultH\x00\x12\x35\n\x10todev_zigzag_ack\x18$ \x01(\x0b\x32\x19.NavUploadZigZagResultAckH\x00\x12&\n\x0etodev_taskctrl\x18% \x01(\x0b\x32\x0c.NavTaskCtrlH\x00\x12%\n\rbidire_taskid\x18& \x01(\x0b\x32\x0c.NavTaskIdRwH\x00\x12&\n\x08toapp_bp\x18\' \x01(\x0b\x32\x12.NavTaskBreakPointH\x00\x12+\n\x11todev_planjob_set\x18( \x01(\x0b\x32\x0e.NavPlanJobSetH\x00\x12\x32\n\x15todev_unable_time_set\x18) \x01(\x0b\x32\x11.NavUnableTimeSetH\x00\x12,\n\x0esimulation_cmd\x18* \x01(\x0b\x32\x12.SimulationCmdDataH\x00\x12<\n\x1ctodev_work_report_update_cmd\x18+ \x01(\x0b\x32\x14.WorkReportUpdateCmdH\x00\x12<\n\x1ctoapp_work_report_update_ack\x18, \x01(\x0b\x32\x14.WorkReportUpdateAckH\x00\x12\x33\n\x15todev_work_report_cmd\x18- \x01(\x0b\x32\x12.WorkReportCmdDataH\x00\x12\x33\n\x15toapp_work_report_ack\x18. \x01(\x0b\x32\x12.WorkReportInfoAckH\x00\x12\x36\n\x18toapp_work_report_upload\x18/ \x01(\x0b\x32\x12.WorkReportInfoAckH\x00\x12=\n\x17\x61pp_request_cover_paths\x18\x30 \x01(\x0b\x32\x1a.app_request_cover_paths_tH\x00\x12\x31\n\x11\x63over_path_upload\x18\x31 \x01(\x0b\x32\x14.cover_path_upload_tH\x00\x12\x33\n\x12zone_start_precent\x18\x32 \x01(\x0b\x32\x15.zone_start_precent_tH\x00\x12\'\n\x0bvision_ctrl\x18\x33 \x01(\x0b\x32\x10.vision_ctrl_msgH\x00\x12/\n\x11nav_sys_param_cmd\x18\x34 \x01(\x0b\x32\x12.nav_sys_param_msgH\x00\x12\x33\n\x11plan_task_execute\x18\x35 \x01(\x0b\x32\x16.nav_plan_task_executeH\x00\x12#\n\rtoapp_costmap\x18\x36 \x01(\x0b\x32\n.costmap_tH\x00\x12\x31\n\x11plan_task_name_id\x18\x37 \x01(\x0b\x32\x14.plan_task_name_id_tH\x00\x12/\n\rall_plan_task\x18\x38 \x01(\x0b\x32\x16.nav_get_all_plan_taskH\x00\x12-\n\x12todev_taskctrl_ack\x18\x39 \x01(\x0b\x32\x0f.NavTaskCtrlAckH\x00\x12,\n\x12toapp_map_name_msg\x18: \x01(\x0b\x32\x0e.NavMapNameMsgH\x00\x12(\n\rtodev_svg_msg\x18; \x01(\x0b\x32\x0f.SvgMessageAckTH\x00\x12(\n\rtoapp_svg_msg\x18< \x01(\x0b\x32\x0f.SvgMessageAckTH\x00\x12\x35\n\x13toapp_all_hash_name\x18= \x01(\x0b\x32\x16.AppGetAllAreaHashNameH\x00\x42\x0b\n\tSubNavMsgb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pymammotion.proto.mctrl_nav_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NAVLATLONUP._serialized_start=69
  _NAVLATLONUP._serialized_end=108
  _NAVBORDERSTATE._serialized_start=110
  _NAVBORDERSTATE._serialized_end=143
  _NAVPOSUP._serialized_start=146
  _NAVPOSUP._serialized_end=347
  _NAVBORDERDATAGETACK._serialized_start=349
  _NAVBORDERDATAGETACK._serialized_end=407
  _NAVOBSTIBORDERDATAGET._serialized_start=409
  _NAVOBSTIBORDERDATAGET._serialized_end=499
  _NAVOBSTIBORDERDATAGETACK._serialized_start=501
  _NAVOBSTIBORDERDATAGETACK._serialized_end=572
  _NAVCHLLINEDATA._serialized_start=574
  _NAVCHLLINEDATA._serialized_end=674
  _NAVCHLLINEDATAACK._serialized_start=676
  _NAVCHLLINEDATAACK._serialized_end=755
  _NAVTASKINFO._serialized_start=757
  _NAVTASKINFO._serialized_end=884
  _NAVBORDERDATAGET._serialized_start=886
  _NAVBORDERDATAGET._serialized_end=960
  _NAVOPTLINEUP._serialized_start=963
  _NAVOPTLINEUP._serialized_end=1108
  _NAVOPTIBORDERINFO._serialized_start=1110
  _NAVOPTIBORDERINFO._serialized_end=1236
  _NAVOPTOBSINFO._serialized_start=1239
  _NAVOPTOBSINFO._serialized_end=1368
  _NAVSTARTJOB._serialized_start=1371
  _NAVSTARTJOB._serialized_end=1551
  _NAVTASKPROGRESS._serialized_start=1553
  _NAVTASKPROGRESS._serialized_end=1592
  _NAVRESFRAME._serialized_start=1594
  _NAVRESFRAME._serialized_end=1624
  _NAVGETHASHLIST._serialized_start=1626
  _NAVGETHASHLIST._serialized_end=1750
  _NAVGETHASHLISTACK._serialized_start=1753
  _NAVGETHASHLISTACK._serialized_end=1933
  _NAVGETCOMMDATA._serialized_start=1936
  _NAVGETCOMMDATA._serialized_end=2150
  _AREALABEL._serialized_start=2152
  _AREALABEL._serialized_end=2178
  _NAVGETCOMMDATAACK._serialized_start=2181
  _NAVGETCOMMDATAACK._serialized_end=2499
  _NAVREQCOVERPATH._serialized_start=2502
  _NAVREQCOVERPATH._serialized_end=2852
  _NAVUPLOADZIGZAGRESULT._serialized_start=2855
  _NAVUPLOADZIGZAGRESULT._serialized_end=3278
  _NAVUPLOADZIGZAGRESULTACK._serialized_start=3281
  _NAVUPLOADZIGZAGRESULTACK._serialized_end=3457
  _NAVTASKCTRL._serialized_start=3459
  _NAVTASKCTRL._serialized_end=3536
  _NAVTASKIDRW._serialized_start=3538
  _NAVTASKIDRW._serialized_end=3649
  _NAVSYSHASHOVERVIEW._serialized_start=3651
  _NAVSYSHASHOVERVIEW._serialized_end=3725
  _NAVTASKBREAKPOINT._serialized_start=3727
  _NAVTASKBREAKPOINT._serialized_end=3832
  _NAVPLANJOBSET._serialized_start=3835
  _NAVPLANJOBSET._serialized_end=4541
  _NAVUNABLETIMESET._serialized_start=4544
  _NAVUNABLETIMESET._serialized_end=4678
  _CHARGEPILETYPE._serialized_start=4680
  _CHARGEPILETYPE._serialized_end=4734
  _SIMULATIONCMDDATA._serialized_start=4736
  _SIMULATIONCMDDATA._serialized_end=4810
  _WORKREPORTUPDATECMD._serialized_start=4812
  _WORKREPORTUPDATECMD._serialized_end=4849
  _WORKREPORTUPDATEACK._serialized_start=4851
  _WORKREPORTUPDATEACK._serialized_end=4911
  _WORKREPORTCMDDATA._serialized_start=4913
  _WORKREPORTCMDDATA._serialized_end=4968
  _WORKREPORTINFOACK._serialized_start=4971
  _WORKREPORTINFOACK._serialized_end=5241
  _APP_REQUEST_COVER_PATHS_T._serialized_start=5244
  _APP_REQUEST_COVER_PATHS_T._serialized_end=5422
  _COVER_PATH_PACKET_T._serialized_start=5425
  _COVER_PATH_PACKET_T._serialized_end=5578
  _COVER_PATH_UPLOAD_T._serialized_start=5581
  _COVER_PATH_UPLOAD_T._serialized_end=5887
  _ZONE_START_PRECENT_T._serialized_start=5889
  _ZONE_START_PRECENT_T._serialized_end=5966
  _VISION_CTRL_MSG._serialized_start=5968
  _VISION_CTRL_MSG._serialized_end=6012
  _NAV_SYS_PARAM_MSG._serialized_start=6014
  _NAV_SYS_PARAM_MSG._serialized_end=6074
  _NAV_PLAN_TASK_EXECUTE._serialized_start=6076
  _NAV_PLAN_TASK_EXECUTE._serialized_end=6157
  _COSTMAP_T._serialized_start=6159
  _COSTMAP_T._serialized_end=6280
  _PLAN_TASK_NAME_ID_T._serialized_start=6282
  _PLAN_TASK_NAME_ID_T._serialized_end=6329
  _NAV_GET_ALL_PLAN_TASK._serialized_start=6331
  _NAV_GET_ALL_PLAN_TASK._serialized_end=6391
  _NAVTASKCTRLACK._serialized_start=6393
  _NAVTASKCTRLACK._serialized_end=6492
  _NAVMAPNAMEMSG._serialized_start=6494
  _NAVMAPNAMEMSG._serialized_end=6584
  _SVG_MESSAGE_T._serialized_start=6587
  _SVG_MESSAGE_T._serialized_end=6863
  _SVGMESSAGEACKT._serialized_start=6866
  _SVGMESSAGEACKT._serialized_end=7068
  _AREAHASHNAME._serialized_start=7070
  _AREAHASHNAME._serialized_end=7112
  _APPGETALLAREAHASHNAME._serialized_start=7114
  _APPGETALLAREAHASHNAME._serialized_end=7190
  _MCTLNAV._serialized_start=7193
  _MCTLNAV._serialized_end=9852
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pymammotion/proto/luba_mul.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n pymammotion/proto/luba_mul.proto\"V\n\x0bMulSetAudio\x12\x13\n\tat_switch\x18\x01 \x01(\x05H\x00\x12$\n\x0b\x61u_language\x18\x02 \x01(\x0e\x32\r.MUL_LANGUAGEH\x00\x42\x0c\n\nAudioCfg_u\"H\n\x0bMulSetVideo\x12&\n\x08position\x18\x01 \x01(\x0e\x32\x14.MUL_CAMERA_POSITION\x12\x11\n\tvi_switch\x18\x02 \x01(\x05\";\n\x0eMulSetVideoAck\x12)\n\nerror_code\x18\x01 \x01(\x0e\x32\x15.MUL_VIDEO_ERROR_CODE\"D\n\x0bMulAudioCfg\x12\x11\n\tau_switch\x18\x01 \x01(\x05\x12\"\n\x0b\x61u_language\x18\x02 \x01(\x0e\x32\r.MUL_LANGUAGE\"\x1c\n\x0bMulSetWiper\x12\r\n\x05round\x18\x01 \x01(\x05\";\n\x0eMulSetWiperAck\x12)\n\nerror_code\x18\x01 \x01(\x0e\x32\x15.MUL_WIPER_ERROR_CODE\"\xf2\x01\n\x06SocMul\x12!\n\tset_audio\x18\x01 \x01(\x0b\x32\x0c.MulSetAudioH\x00\x12!\n\taudio_cfg\x18\x02 \x01(\x0b\x32\x0c.MulAudioCfgH\x00\x12!\n\tset_video\x18\x03 \x01(\x0b\x32\x0c.MulSetVideoH\x00\x12(\n\rset_video_ack\x18\x04 \x01(\x0b\x32\x0f.MulSetVideoAckH\x00\x12!\n\tset_wiper\x18\x05 \x01(\x0b\x32\x0c.MulSetWiperH\x00\x12(\n\rset_wiper_ack\x18\x06 \x01(\x0b\x32\x0f.MulSetWiperAckH\x00\x42\x08\n\x06SubMul*B\n\x0cMUL_LANGUAGE\x12\x0b\n\x07\x45NGLISH\x10\x00\x12\n\n\x06GERMAN\x10\x01\x12\x19\n\x0cUNRECOGNIZED\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*=\n\x13MUL_CAMERA_POSITION\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\x08\n\x04REAR\x10\x02\x12\x07\n\x03\x41LL\x10\x03*\x9d\x01\n\x14MUL_VIDEO_ERROR_CODE\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x41\x43TIVATION_FAILED\x10\x01\x12\x19\n\x15NETWORK_NOT_AVAILABLE\x10\x02\x12\x19\n\x15\x43REATE_CHANNEL_FAILED\x10\x03\x12\x11\n\rPARAM_INVAILD\x10\x04\x12\x18\n\x14\x43\x45LLULAR_RESTRICTION\x10\x05*Q\n\x14MUL_WIPER_ERROR_CODE\x12\x0f\n\x0bSET_SUCCESS\x10\x00\x12\x0c\n\x08HW_ERROR\x10\x01\x12\x1a\n\x16NAVIGATION_WORK_FORBID\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pymammotion.proto.luba_mul_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MUL_LANGUAGE._serialized_start=665
  _MUL_LANGUAGE._serialized_end=731
  _MUL_CAMERA_POSITION._serialized_start=733
  _MUL_CAMERA_POSITION._serialized_end=794
  _MUL_VIDEO_ERROR_CODE._serialized_start=797
  _MUL_VIDEO_ERROR_CODE._serialized_end=954
  _MUL_WIPER_ERROR_CODE._serialized_start=956
  _MUL_WIPER_ERROR_CODE._serialized_end=1037
  _MULSETAUDIO._serialized_start=36
  _MULSETAUDIO._serialized_end=122
  _MULSETVIDEO._serialized_start=124
  _MULSETVIDEO._serialized_end=196
  _MULSETVIDEOACK._serialized_start=198
  _MULSETVIDEOACK._serialized_end=257
  _MULAUDIOCFG._serialized_start=259
  _MULAUDIOCFG._serialized_end=327
  _MULSETWIPER._serialized_start=329
  _MULSETWIPER._serialized_end=357
  _MULSETWIPERACK._serialized_start=359
  _MULSETWIPERACK._serialized_end=418
  _SOCMUL._serialized_start=421
  _SOCMUL._serialized_end=663
# @@protoc_insertion_point(module_scope)
